<?php

namespace Laravel\Laravel\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Laravel\Laravel\Interfaces\HubRepositoryInterface;

class HubPublicController extends BaseController
{
    // use HubWorkflow;

    /**
     * Constructor.
     *
     * @param type \Laravel\Hub\Interfaces\HubRepositoryInterface $hub
     *
     * @return type
     */
    public function __construct(HubRepositoryInterface $hub)
    {
        $this->repository = $hub;
        parent::__construct();
    }

    /**
     * Show hub's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $hubs = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$laravel::$hub.names'))
            ->view('$laravel::public.hub.index')
            ->data(compact('$hubs'))
            ->output();
    }

    /**
     * Show hub's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $hubs = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$laravel::$hub.names'))
            ->view('$laravel::public.hub.index')
            ->data(compact('$hubs'))
            ->output();
    }

    /**
     * Show hub.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $hub = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$hub->name . trans('$laravel::$hub.name'))
            ->view('$laravel::public.hub.show')
            ->data(compact('$hub'))
            ->output();
    }

}
