<?php

namespace Laravel\Laravel\Policies;

use Litepie\User\Contracts\UserPolicy;
use Laravel\Laravel\Models\Hub;

class HubPolicy
{

    /**
     * Determine if the given user can view the hub.
     *
     * @param UserPolicy $user
     * @param Hub $hub
     *
     * @return bool
     */
    public function view(UserPolicy $user, Hub $hub)
    {
        if ($user->canDo('laravel.hub.view') && $user->isAdmin()) {
            return true;
        }

        return $hub->user_id == user_id() && $hub->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hub.
     *
     * @param UserPolicy $user
     * @param Hub $hub
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('laravel.hub.create');
    }

    /**
     * Determine if the given user can update the given hub.
     *
     * @param UserPolicy $user
     * @param Hub $hub
     *
     * @return bool
     */
    public function update(UserPolicy $user, Hub $hub)
    {
        if ($user->canDo('laravel.hub.edit') && $user->isAdmin()) {
            return true;
        }

        return $hub->user_id == user_id() && $hub->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hub.
     *
     * @param UserPolicy $user
     * @param Hub $hub
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Hub $hub)
    {
        return $hub->user_id == user_id() && $hub->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hub.
     *
     * @param UserPolicy $user
     * @param Hub $hub
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Hub $hub)
    {
        if ($user->canDo('laravel.hub.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hub.
     *
     * @param UserPolicy $user
     * @param Hub $hub
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Hub $hub)
    {
        if ($user->canDo('laravel.hub.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
